==> hqsoft_core-0.0.40.tar.gz: lib/core_base/widgets/box_field_customize.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:hqsoft_core/core_base/core_base.dart';
import 'package:hqsoft_core/value_base/colors.dart';
import 'package:hqsoft_core/value_base/theme_base.dart';

class BoxFieldCustomize extends StatefulWidget {
  final TextEditingController controller;
  final FocusNode focusNode;
  final TextInputType keyboardType;
  final TextInputAction textInputAction;
  final TextCapitalization textCapitalization;
  final TextStyle style;
  final TextStyle hintStyle;
  final TextAlign textAlign;
  final bool isRequired;
  final bool autoFocus;
  final bool obscureText;
  final bool autoCorrect;
  final int maxLines;
  final String keyString;
  final int maxLength;
  final bool maxLengthEnforced;
  final ValueChanged<String> onChanged;
  final VoidCallback onEditingComplete;
  final ValueChanged<String> onSubmitted;
  final List<TextInputFormatter> inputFormatter;
  final bool enabled;
  final Color iconColor;
  final Color focusBorderColor;
  final String hintText;
  final double cursorWidth;
  final Radius cursorRadius;
  final Color cursorColor;
  final double heightCont;
  final Color defaultBorderColor;
  final Brightness keyboardAppearance;
  final EdgeInsets scrollPadding;
  final FormFieldValidator<String> validator;
  final ValueChanged<String> onFieldSubmitted;
  final Widget prefixIcon;
  final IconData iconData;
  final bool isTypePassword;

  final FormFieldSetter<String> onSaved;

  const BoxFieldCustomize({
    this.keyString,
    this.controller,
    this.heightCont,
    this.focusNode,
    this.keyboardType,
    this.textInputAction,
    this.textCapitalization = TextCapitalization.none,
    this.style,
    this.hintStyle,
    this.textAlign = TextAlign.start,
    this.isRequired = false,
    this.autoFocus = false,
    this.obscureText = false,
    this.autoCorrect = true,
    this.maxLines = 1,
    this.maxLength,
    this.onSaved,
    this.hintText,
    this.maxLengthEnforced = true,
    this.onChanged,
    this.defaultBorderColor,
    this.onEditingComplete,
    this.onSubmitted,
    this.iconColor,
    this.inputFormatter,
    this.enabled,
    this.cursorWidth = 2.0,
    this.cursorRadius,
    this.cursorColor,
    this.focusBorderColor,
    this.keyboardAppearance,
    this.scrollPadding,
    this.validator,
    this.onFieldSubmitted,
    this.prefixIcon,
    this.iconData,
    this.isTypePassword = false,
  })  : assert(textAlign != null),
        assert(isRequired != null),
        assert(autoFocus != null),
        assert(obscureText != null),
        assert(autoCorrect != null),
        assert(maxLengthEnforced != null),
        assert(maxLines == null || maxLines > 0),
        assert(maxLength == null || maxLength > 0);

//        keyboardType = keyboardType ??
//            (maxLines == 1 ? TextInputType.text : TextInputType.multiline);

  @override
  _BoxFieldCustomizeState createState() => _BoxFieldCustomizeState();
}

class _BoxFieldCustomizeState extends State<BoxFieldCustomize> {
  Color focusBorderColor = Colors.grey.shade400;
  FocusNode _focusNode = FocusNode();
  double heightCont;
  double iconSize;
  ValueChanged<Colors> focusColorChange;
  bool _isHidePassword = true;
  bool _isHasFocus = false;

  void _togglePasswordVisibility() {
    setState(() {
      _isHidePassword = !_isHidePassword;
    });
  }

  @override
  void initState() {
    super.initState();
    _focusNodeListener();
  }

  @override
  void dispose() {
    super.dispose();
    _focusNode.dispose();
    widget.focusNode.removeListener(() {});
  }

  void _focusNodeListener() {
    widget.focusNode.addListener(() {
      if (this.mounted) {
        setState(() {
          _isHasFocus = widget.focusNode.hasFocus;
        });
      }
    });
  }

  @override
  Widget build(BuildContext context) {
    heightCont = widget.heightCont == null ? 45 : widget.heightCont;
    iconSize = widget.heightCont == null ? 24 : 18;

    return Container(
      child: Row(
        crossAxisAlignment: CrossAxisAlignment.center,
        mainAxisAlignment: MainAxisAlignment.center,
        children: <Widget>[
          Expanded(
            child: Container(
              //margin: EdgeInsets.only(top: height / 400),
              padding: EdgeInsets.all(ScreenConfig.getWidthPx(0)),
              alignment: Alignment.center,
              height: ScreenConfig.getWidthPx(heightCont.toInt()),
              decoration: BoxDecoration(
                color: Colors.white,
                border: Border.all(
                  color: _isHasFocus ? colorTextFocus : colorHintText,
                  width: _isHasFocus ? 1.5 : 1.0,
                ),
                borderRadius: BorderRadius.circular(12.0),
              ),
              child: Row(
                mainAxisAlignment: MainAxisAlignment.center,
                children: [
                  widget.iconData != null
                      ? Container(
                          margin: EdgeInsets.only(
                            left: ScreenConfig.getWidthPx(10),
                            right: ScreenConfig.getWidthPx(10),
                          ),
                          width: ScreenConfig.getWidthPx(24),
                          height: ScreenConfig.getWidthPx(24),
                          child: Icon(
                            widget.iconData,
                            color: _isHasFocus ? colorTextFocus : colorHintText,
                            size: 20,
                          ),
                        )
                      : Container(),
                  Expanded(
                    child: TextFormField(
                      key: Key(widget.keyString),
                      style: ThemeBase.textRobotoCustomize(
                        color: _isHasFocus ? colorTextFocus : colorHintText,
                        fontWeight: FontWeight.w400,
                        fontSize: 16,
                      ),
                      obscureText: widget.isTypePassword ? _isHidePassword : false,
                      autofocus: false,
                      controller: widget.controller,
                      onSaved: widget.onSaved,
                      validator: widget.validator,
                      focusNode: widget.focusNode,
                      onFieldSubmitted: widget.onFieldSubmitted,
                      keyboardType: widget.keyboardType == null
                          ? (widget.maxLines == 1 ? TextInputType.text : TextInputType.multiline)
                          : widget.keyboardType,
                      textInputAction: widget.textInputAction,
                      decoration: InputDecoration(
                        contentPadding: EdgeInsets.only(
                          top: ScreenConfig.getWidthPx(16),
                          bottom: ScreenConfig.getWidthPx(12),
                        ),
                        border: InputBorder.none,
                        suffixIcon: widget.isTypePassword
                            ? GestureDetector(
                                onTap: () {
                                  _togglePasswordVisibility();
                                },
                                child: Icon(
                                  !_isHidePassword ? FontAwesomeIcons.eyeSlash : FontAwesomeIcons.eye,
                                  color: _isHasFocus ? colorTextFocus : colorHintText,
                                  size: 20,
                                ),
                              )
                            : null,
                        hintStyle: ThemeBase.textRobotoRegular16(),
                        hintText: widget.hintText,
                      ),
                    ),
                  ),
                ],
              ),
            ),
          ),
          widget.isRequired ? Text(" * ", style: ThemeBase.textHaveRequired) : Container(),
        ],
      ),
      margin: EdgeInsets.only(
        top: ScreenConfig.getWidthPx(8),
        left: ScreenConfig.getWidthPx(15),
        right: ScreenConfig.getWidthPx(15),
      ),
    );
  }
}

==> hqsoft_core-0.0.63.tar.gz: lib/core_base/widgets/box_field_customize.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:hqsoft_core/core_base/core_base.dart';
import 'package:hqsoft_core/value_base/colors.dart';
import 'package:hqsoft_core/value_base/theme_base.dart';

class BoxFieldCustomize extends StatefulWidget {
  final TextEditingController? controller;
  final FocusNode? focusNode;
  final TextInputType? keyboardType;
  final TextInputAction? textInputAction;
  final TextCapitalization? textCapitalization;
  final TextStyle? style;
  final TextStyle? hintStyle;
  final TextAlign? textAlign;
  final bool isRequired;
  final bool autoFocus;
  final bool obscureText;
  final bool autoCorrect;
  final int maxLines;
  final String? keyString;
  final int? maxLength;
  final bool maxLengthEnforced;
  final ValueChanged<String>? onChanged;
  final VoidCallback? onEditingComplete;
  final ValueChanged<String>? onSubmitted;
  final List<TextInputFormatter>? inputFormatter;
  final bool? enabled;
  final Color? iconColor;
  final Color? focusBorderColor;
  final String? hintText;
  final double? cursorWidth;
  final Radius? cursorRadius;
  final Color? cursorColor;
  final double? heightCont;
  final Color? defaultBorderColor;
  final Brightness? keyboardAppearance;
  final EdgeInsets? scrollPadding;
  final FormFieldValidator<String>? validator;
  final ValueChanged<String>? onFieldSubmitted;
  final Widget? prefixIcon;
  final IconData? iconData;
  final bool isTypePassword;

  final FormFieldSetter<String>? onSaved;

  const BoxFieldCustomize({
    this.keyString,
    this.controller,
    this.heightCont,
    this.focusNode,
    this.keyboardType,
    this.textInputAction,
    this.textCapitalization = TextCapitalization.none,
    this.style,
    this.hintStyle,
    this.textAlign = TextAlign.start,
    this.isRequired = false,
    this.autoFocus = false,
    this.obscureText = false,
    this.autoCorrect = true,
    this.maxLines = 1,
    this.maxLength,
    this.onSaved,
    this.hintText,
    this.maxLengthEnforced = true,
    this.onChanged,
    this.defaultBorderColor,
    this.onEditingComplete,
    this.onSubmitted,
    this.iconColor,
    this.inputFormatter,
    this.enabled,
    this.cursorWidth = 2.0,
    this.cursorRadius,
    this.cursorColor,
    this.focusBorderColor,
    this.keyboardAppearance,
    this.scrollPadding,
    this.validator,
    this.onFieldSubmitted,
    this.prefixIcon,
    this.iconData,
    this.isTypePassword = false,
  })  : assert(textAlign != null),
        assert(isRequired != null),
        assert(autoFocus != null),
        assert(obscureText != null),
        assert(autoCorrect != null),
        assert(maxLengthEnforced != null),
        assert(maxLines == null || maxLines > 0),
        assert(maxLength == null || maxLength > 0);

//        keyboardType = keyboardType ??
//            (maxLines == 1 ? TextInputType.text : TextInputType.multiline);

  @override
  _BoxFieldCustomizeState createState() => _BoxFieldCustomizeState();
}

class _BoxFieldCustomizeState extends State<BoxFieldCustomize> {
  Color focusBorderColor = Colors.grey.shade400;
  FocusNode _focusNode = FocusNode();
  double? heightCont;
  double? iconSize;
  ValueChanged<Colors>? focusColorChange;
  bool _isHidePassword = true;
  bool _isHasFocus = false;

  void _togglePasswordVisibility() {
    setState(() {
      _isHidePassword = !_isHidePassword;
    });
  }

  @override
  void initState() {
    super.initState();
    _focusNodeListener();
  }

  @override
  void dispose() {
    super.dispose();
    _focusNode.dispose();
    widget.focusNode!.removeListener(() {});
  }

  void _focusNodeListener() {
    widget.focusNode!.addListener(() {
      if (this.mounted) {
        setState(() {
          _isHasFocus = widget.focusNode!.hasFocus;
        });
      }
    });
  }

  @override
  Widget build(BuildContext context) {
    heightCont = widget.heightCont == null ? 45 : widget.heightCont;
    iconSize = widget.heightCont == null ? 24 : 18;

    return Container(
      child: Row(
        crossAxisAlignment: CrossAxisAlignment.center,
        mainAxisAlignment: MainAxisAlignment.center,
        children: <Widget>[
          Expanded(
            child: Container(
              //margin: EdgeInsets.only(top: height / 400),
              padding: EdgeInsets.all(ScreenConfig.getWidthPx(0)),
              alignment: Alignment.center,
              height: ScreenConfig.getWidthPx(heightCont!.toInt()),
              decoration: BoxDecoration(
                color: Colors.white,
                border: Border.all(
                  color: _isHasFocus ? colorTextFocus : colorHintText,
                  width: _isHasFocus ? 1.5 : 1.0,
                ),
                borderRadius: BorderRadius.circular(12.0),
              ),
              child: Row(
                mainAxisAlignment: MainAxisAlignment.center,
                children: [
                  widget.iconData != null
                      ? Container(
                          margin: EdgeInsets.only(
                            left: ScreenConfig.getWidthPx(10),
                            right: ScreenConfig.getWidthPx(10),
                          ),
                          width: ScreenConfig.getWidthPx(24),
                          height: ScreenConfig.getWidthPx(24),
                          child: Icon(
                            widget.iconData,
                            color: _isHasFocus ? colorTextFocus : colorHintText,
                            size: 20,
                          ),
                        )
                      : Container(),
                  Expanded(
                    child: TextFormField(
                      key: Key(widget.keyString??''),
                      style: ThemeBase.textRobotoCustomize(
                        color: _isHasFocus ? colorTextFocus : colorHintText,
                        fontWeight: FontWeight.w400,
                        fontSize: 16,
                      ),
                      obscureText: widget.isTypePassword ? _isHidePassword : false,
                      autofocus: false,
                      controller: widget.controller,
                      onSaved: widget.onSaved,
                      validator: widget.validator,
                      focusNode: widget.focusNode,
                      onFieldSubmitted: widget.onFieldSubmitted,
                      keyboardType: widget.keyboardType == null
                          ? (widget.maxLines == 1 ? TextInputType.text : TextInputType.multiline)
                          : widget.keyboardType,
                      textInputAction: widget.textInputAction,
                      decoration: InputDecoration(
                        contentPadding: EdgeInsets.only(
                          top: ScreenConfig.getWidthPx(16),
                          bottom: ScreenConfig.getWidthPx(12),
                        ),
                        border: InputBorder.none,
                        suffixIcon: widget.isTypePassword
                            ? GestureDetector(
                                onTap: () {
                                  _togglePasswordVisibility();
                                },
                                child: Icon(
                                  !_isHidePassword ? FontAwesomeIcons.eyeSlash : FontAwesomeIcons.eye,
                                  color: _isHasFocus ? colorTextFocus : colorHintText,
                                  size: 20,
                                ),
                              )
                            : null,
                        hintStyle: ThemeBase.textRobotoRegular16(),
                        hintText: widget.hintText,
                      ),
                    ),
                  ),
                ],
              ),
            ),
          ),
          widget.isRequired ? Text(" * ", style: ThemeBase.textHaveRequired) : Container(),
        ],
      ),
      margin: EdgeInsets.only(
        top: ScreenConfig.getWidthPx(8),
        left: ScreenConfig.getWidthPx(15),
        right: ScreenConfig.getWidthPx(15),
      ),
    );
  }
}
